@@ -980,7 +980,7 @@ class StartingPointFinder(object):
         self.significance = significance
         "The significance calculator."
         
-        self.central_widths = self.options.widths and self.options.widths or list(geometric_progression(self.options.min_w, self.options.max_w, N.sqrt(2.)))
+        self.central_widths = self.options.width and self.options.width or list(geometric_progression(self.options.min_w, self.options.max_w, N.sqrt(2.)))
         "The widths for which we will find starts."
         logger.info('Looking for motifs of widths: %s', ', '.join([('%d' % w) for w in self.central_widths]))
         
@@ -1863,8 +1863,8 @@ class Algorithm(object):
     def __init__(self, options):
         "Initialise."
         self.options = options
-        if self.options.widths:
-            self.options.max_w = max(self.options.widths) # make sure max_w is correct
+        if self.options.width:
+            self.options.max_w = max(self.options.width) # make sure max_w is correct
         ensure_dir_exists(self.options.output_dir)          
         self.name = 'STEM'
         self._setup_logging()
